clear all
clc
format compact

global TRPMILE WTTRDFIN WTSUM
dmax=200;

%Read NHTS-2009 data from from totaldistandweights2009nozeros.csv
NHTS = dlmread('totaldistandweights2009nozeros.csv',',');
N = sum(NHTS(:,1)<=200);
TRPMILE=NHTS(1:N,1); 
WTTRDFIN=NHTS(1:N,2)*1e-7;
WTSUM=sum(WTTRDFIN);
clear NHTS

% scaling NHTS weights to avoid super-big numbers in optimization
bin_size=1;
bin_num=dmax/bin_size;
bin=zeros(1,bin_num);
xfit=bin_size:bin_size:dmax;
k=1;
% loop to add up weights in each bin
for i=1:bin_num, % 200 bins, each bin take 1 miles
    u=i*bin_size;
    while(TRPMILE(k)<=u && k<N),
        bin(i)=bin(i)+WTTRDFIN(k);
        k=k+1;
    end
end

% to fit the data with maximum likelihood method with Weibull distributon
opts = optimset('LargeScale','off','Display','iter','FinDiffType','central','Algorithm','Active-Set',...
                   'MaxFunEvals',1000,'TolX',1e-9,'TolFun',1e-9);
[lambda,nLL,exitflag,output,grad,hessian]=fminunc(@loglkexp,0.01,opts);
%[lambda,nLL,exitflag,output]=ktrlink(@loglkexp,0.01);
disp(sprintf('Exponential distribution parameter lambda = %0.6f',lambda));
pdffit = lambda*exp(-1*lambda*(1:bin_size:dmax));

%%% plot probability
%%% bin2 and bin2_size are for plotting histogram only (2 mile interval)
k=1;
bin2_size=2;
bin2=zeros(1,100);
% loop to add up weights in each bin
for i=1:100,
    u=i*bin2_size;
    while(TRPMILE(k)<=u && k<N),
        bin2(i)=bin2(i)+WTTRDFIN(k);
        k=k+1;
    end
end
binprob=bin2/WTSUM;
figure; bar(2:2:200,binprob/bin2_size,'hist'); xlim([0,dmax]);
h = get(gca,'child');
set(h,'FaceColor',[.1 .9 0]);
xlabel('Daily driving miles'); ylabel('Weighted probability')
hold on
% plot the fitted pdf curve
line(xfit,pdffit,'LineWidth',2.5,'Color',[0 0 1]);
